"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AcceptedPortfolioShare(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    accept_language: builtins.str
    portfolio_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "portfolio_id", b"portfolio_id", "resource_info", b"resource_info"]) -> None: ...

global___AcceptedPortfolioShare = AcceptedPortfolioShare

@typing_extensions.final
class ServiceCatalog(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACCEPTED_PORTFOLIO_SHARE_FIELD_NUMBER: builtins.int
    CLOUD_FORMATION_PRODUCT_FIELD_NUMBER: builtins.int
    CLOUD_FORMATION_PROVISIONED_PRODUCT_FIELD_NUMBER: builtins.int
    LAUNCH_NOTIFICATION_CONSTRAINT_FIELD_NUMBER: builtins.int
    LAUNCH_ROLE_CONSTRAINT_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_CONSTRAINT_FIELD_NUMBER: builtins.int
    PORTFOLIO_FIELD_NUMBER: builtins.int
    PORTFOLIO_PRINCIPAL_ASSOCIATION_FIELD_NUMBER: builtins.int
    PORTFOLIO_PRODUCT_ASSOCIATION_FIELD_NUMBER: builtins.int
    PORTFOLIO_SHARE_FIELD_NUMBER: builtins.int
    RESOURCE_UPDATE_CONSTRAINT_FIELD_NUMBER: builtins.int
    STACK_SET_CONSTRAINT_FIELD_NUMBER: builtins.int
    TAG_OPTION_FIELD_NUMBER: builtins.int
    TAG_OPTION_ASSOCIATION_FIELD_NUMBER: builtins.int
    @property
    def accepted_portfolio_share(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___AcceptedPortfolioShare]: ...
    @property
    def cloud_formation_product(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudFormationProduct]: ...
    @property
    def cloud_formation_provisioned_product(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudFormationProvisionedProduct]: ...
    @property
    def launch_notification_constraint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchNotificationConstraint]: ...
    @property
    def launch_role_constraint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchRoleConstraint]: ...
    @property
    def launch_template_constraint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___LaunchTemplateConstraint]: ...
    @property
    def portfolio(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Portfolio]: ...
    @property
    def portfolio_principal_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortfolioPrincipalAssociation]: ...
    @property
    def portfolio_product_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortfolioProductAssociation]: ...
    @property
    def portfolio_share(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PortfolioShare]: ...
    @property
    def resource_update_constraint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ResourceUpdateConstraint]: ...
    @property
    def stack_set_constraint(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___StackSetConstraint]: ...
    @property
    def tag_option(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TagOption]: ...
    @property
    def tag_option_association(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___TagOptionAssociation]: ...
    def __init__(
        self,
        *,
        accepted_portfolio_share: collections.abc.Iterable[global___AcceptedPortfolioShare] | None = ...,
        cloud_formation_product: collections.abc.Iterable[global___CloudFormationProduct] | None = ...,
        cloud_formation_provisioned_product: collections.abc.Iterable[global___CloudFormationProvisionedProduct] | None = ...,
        launch_notification_constraint: collections.abc.Iterable[global___LaunchNotificationConstraint] | None = ...,
        launch_role_constraint: collections.abc.Iterable[global___LaunchRoleConstraint] | None = ...,
        launch_template_constraint: collections.abc.Iterable[global___LaunchTemplateConstraint] | None = ...,
        portfolio: collections.abc.Iterable[global___Portfolio] | None = ...,
        portfolio_principal_association: collections.abc.Iterable[global___PortfolioPrincipalAssociation] | None = ...,
        portfolio_product_association: collections.abc.Iterable[global___PortfolioProductAssociation] | None = ...,
        portfolio_share: collections.abc.Iterable[global___PortfolioShare] | None = ...,
        resource_update_constraint: collections.abc.Iterable[global___ResourceUpdateConstraint] | None = ...,
        stack_set_constraint: collections.abc.Iterable[global___StackSetConstraint] | None = ...,
        tag_option: collections.abc.Iterable[global___TagOption] | None = ...,
        tag_option_association: collections.abc.Iterable[global___TagOptionAssociation] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["accepted_portfolio_share", b"accepted_portfolio_share", "cloud_formation_product", b"cloud_formation_product", "cloud_formation_provisioned_product", b"cloud_formation_provisioned_product", "launch_notification_constraint", b"launch_notification_constraint", "launch_role_constraint", b"launch_role_constraint", "launch_template_constraint", b"launch_template_constraint", "portfolio", b"portfolio", "portfolio_principal_association", b"portfolio_principal_association", "portfolio_product_association", b"portfolio_product_association", "portfolio_share", b"portfolio_share", "resource_update_constraint", b"resource_update_constraint", "stack_set_constraint", b"stack_set_constraint", "tag_option", b"tag_option", "tag_option_association", b"tag_option_association"]) -> None: ...

global___ServiceCatalog = ServiceCatalog

@typing_extensions.final
class CloudFormationProductProvisioningArtifactProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class InfoEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISABLE_TEMPLATE_VALIDATION_FIELD_NUMBER: builtins.int
    INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    disable_template_validation: builtins.bool
    @property
    def info(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        disable_template_validation: builtins.bool = ...,
        info: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "disable_template_validation", b"disable_template_validation", "info", b"info", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___CloudFormationProductProvisioningArtifactProperties = CloudFormationProductProvisioningArtifactProperties

@typing_extensions.final
class CloudFormationProduct(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    REPLACE_PROVISIONING_ARTIFACTS_FIELD_NUMBER: builtins.int
    OWNER_FIELD_NUMBER: builtins.int
    SUPPORT_DESCRIPTION_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISTRIBUTOR_FIELD_NUMBER: builtins.int
    SUPPORT_EMAIL_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    SUPPORT_URL_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROVISIONING_ARTIFACT_PARAMETERS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    replace_provisioning_artifacts: builtins.bool
    owner: builtins.str
    support_description: builtins.str
    description: builtins.str
    distributor: builtins.str
    support_email: builtins.str
    accept_language: builtins.str
    support_url: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    @property
    def provisioning_artifact_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudFormationProductProvisioningArtifactProperties]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        replace_provisioning_artifacts: builtins.bool = ...,
        owner: builtins.str = ...,
        support_description: builtins.str = ...,
        description: builtins.str = ...,
        distributor: builtins.str = ...,
        support_email: builtins.str = ...,
        accept_language: builtins.str = ...,
        support_url: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
        provisioning_artifact_parameters: collections.abc.Iterable[global___CloudFormationProductProvisioningArtifactProperties] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "distributor", b"distributor", "name", b"name", "owner", b"owner", "provisioning_artifact_parameters", b"provisioning_artifact_parameters", "replace_provisioning_artifacts", b"replace_provisioning_artifacts", "resource_info", b"resource_info", "support_description", b"support_description", "support_email", b"support_email", "support_url", b"support_url", "tags", b"tags"]) -> None: ...

global___CloudFormationProduct = CloudFormationProduct

@typing_extensions.final
class CloudFormationProvisionedProductProvisioningParameter(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___CloudFormationProvisionedProductProvisioningParameter = CloudFormationProvisionedProductProvisioningParameter

@typing_extensions.final
class CloudFormationProvisionedProductProvisioningPreferences(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STACK_SET_ACCOUNTS_FIELD_NUMBER: builtins.int
    STACK_SET_FAILURE_TOLERANCE_COUNT_FIELD_NUMBER: builtins.int
    STACK_SET_FAILURE_TOLERANCE_PERCENTAGE_FIELD_NUMBER: builtins.int
    STACK_SET_MAX_CONCURRENCY_COUNT_FIELD_NUMBER: builtins.int
    STACK_SET_MAX_CONCURRENCY_PERCENTAGE_FIELD_NUMBER: builtins.int
    STACK_SET_OPERATION_TYPE_FIELD_NUMBER: builtins.int
    STACK_SET_REGIONS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def stack_set_accounts(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    stack_set_failure_tolerance_count: builtins.int
    stack_set_failure_tolerance_percentage: builtins.int
    stack_set_max_concurrency_count: builtins.int
    stack_set_max_concurrency_percentage: builtins.int
    stack_set_operation_type: builtins.str
    @property
    def stack_set_regions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        stack_set_accounts: collections.abc.Iterable[builtins.str] | None = ...,
        stack_set_failure_tolerance_count: builtins.int = ...,
        stack_set_failure_tolerance_percentage: builtins.int = ...,
        stack_set_max_concurrency_count: builtins.int = ...,
        stack_set_max_concurrency_percentage: builtins.int = ...,
        stack_set_operation_type: builtins.str = ...,
        stack_set_regions: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "stack_set_accounts", b"stack_set_accounts", "stack_set_failure_tolerance_count", b"stack_set_failure_tolerance_count", "stack_set_failure_tolerance_percentage", b"stack_set_failure_tolerance_percentage", "stack_set_max_concurrency_count", b"stack_set_max_concurrency_count", "stack_set_max_concurrency_percentage", b"stack_set_max_concurrency_percentage", "stack_set_operation_type", b"stack_set_operation_type", "stack_set_regions", b"stack_set_regions"]) -> None: ...

global___CloudFormationProvisionedProductProvisioningPreferences = CloudFormationProvisionedProductProvisioningPreferences

@typing_extensions.final
class CloudFormationProvisionedProduct(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    NOTIFICATION_ARNS_FIELD_NUMBER: builtins.int
    PATH_ID_FIELD_NUMBER: builtins.int
    PATH_NAME_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    PRODUCT_NAME_FIELD_NUMBER: builtins.int
    PROVISIONED_PRODUCT_NAME_FIELD_NUMBER: builtins.int
    PROVISIONING_ARTIFACT_ID_FIELD_NUMBER: builtins.int
    PROVISIONING_ARTIFACT_NAME_FIELD_NUMBER: builtins.int
    PROVISIONING_PARAMETERS_FIELD_NUMBER: builtins.int
    PROVISIONING_PREFERENCES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    accept_language: builtins.str
    @property
    def notification_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    path_id: builtins.str
    path_name: builtins.str
    product_id: builtins.str
    product_name: builtins.str
    provisioned_product_name: builtins.str
    provisioning_artifact_id: builtins.str
    provisioning_artifact_name: builtins.str
    @property
    def provisioning_parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CloudFormationProvisionedProductProvisioningParameter]: ...
    @property
    def provisioning_preferences(self) -> global___CloudFormationProvisionedProductProvisioningPreferences: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        accept_language: builtins.str = ...,
        notification_arns: collections.abc.Iterable[builtins.str] | None = ...,
        path_id: builtins.str = ...,
        path_name: builtins.str = ...,
        product_id: builtins.str = ...,
        product_name: builtins.str = ...,
        provisioned_product_name: builtins.str = ...,
        provisioning_artifact_id: builtins.str = ...,
        provisioning_artifact_name: builtins.str = ...,
        provisioning_parameters: collections.abc.Iterable[global___CloudFormationProvisionedProductProvisioningParameter] | None = ...,
        provisioning_preferences: global___CloudFormationProvisionedProductProvisioningPreferences | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provisioning_preferences", b"provisioning_preferences", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "notification_arns", b"notification_arns", "path_id", b"path_id", "path_name", b"path_name", "product_id", b"product_id", "product_name", b"product_name", "provisioned_product_name", b"provisioned_product_name", "provisioning_artifact_id", b"provisioning_artifact_id", "provisioning_artifact_name", b"provisioning_artifact_name", "provisioning_parameters", b"provisioning_parameters", "provisioning_preferences", b"provisioning_preferences", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___CloudFormationProvisionedProduct = CloudFormationProvisionedProduct

@typing_extensions.final
class LaunchNotificationConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    NOTIFICATION_ARNS_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    @property
    def notification_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    accept_language: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        notification_arns: collections.abc.Iterable[builtins.str] | None = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "notification_arns", b"notification_arns", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "resource_info", b"resource_info"]) -> None: ...

global___LaunchNotificationConstraint = LaunchNotificationConstraint

@typing_extensions.final
class LaunchRoleConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LOCAL_ROLE_NAME_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    local_role_name: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    role_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        local_role_name: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
        role_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "local_role_name", b"local_role_name", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "resource_info", b"resource_info", "role_arn", b"role_arn"]) -> None: ...

global___LaunchRoleConstraint = LaunchRoleConstraint

@typing_extensions.final
class LaunchTemplateConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    RULES_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    rules: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
        rules: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "resource_info", b"resource_info", "rules", b"rules"]) -> None: ...

global___LaunchTemplateConstraint = LaunchTemplateConstraint

@typing_extensions.final
class Portfolio(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PROVIDER_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    provider_name: builtins.str
    description: builtins.str
    display_name: builtins.str
    accept_language: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        provider_name: builtins.str = ...,
        description: builtins.str = ...,
        display_name: builtins.str = ...,
        accept_language: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "display_name", b"display_name", "provider_name", b"provider_name", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Portfolio = Portfolio

@typing_extensions.final
class PortfolioPrincipalAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PRINCIPAL_ARN_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRINCIPAL_TYPE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    principal_arn: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    principal_type: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        principal_arn: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        principal_type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "portfolio_id", b"portfolio_id", "principal_arn", b"principal_arn", "principal_type", b"principal_type", "resource_info", b"resource_info"]) -> None: ...

global___PortfolioPrincipalAssociation = PortfolioPrincipalAssociation

@typing_extensions.final
class PortfolioProductAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    source_portfolio_id: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source_portfolio_id: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "resource_info", b"resource_info", "source_portfolio_id", b"source_portfolio_id"]) -> None: ...

global___PortfolioProductAssociation = PortfolioProductAssociation

@typing_extensions.final
class PortfolioShare(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCOUNT_ID_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    account_id: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        account_id: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "account_id", b"account_id", "portfolio_id", b"portfolio_id", "resource_info", b"resource_info"]) -> None: ...

global___PortfolioShare = PortfolioShare

@typing_extensions.final
class ResourceUpdateConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    TAG_UPDATE_ON_PROVISIONED_PRODUCT_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    accept_language: builtins.str
    tag_update_on_provisioned_product: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        accept_language: builtins.str = ...,
        tag_update_on_provisioned_product: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "description", b"description", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "resource_info", b"resource_info", "tag_update_on_provisioned_product", b"tag_update_on_provisioned_product"]) -> None: ...

global___ResourceUpdateConstraint = ResourceUpdateConstraint

@typing_extensions.final
class StackSetConstraint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STACK_INSTANCE_CONTROL_FIELD_NUMBER: builtins.int
    ACCEPT_LANGUAGE_FIELD_NUMBER: builtins.int
    PORTFOLIO_ID_FIELD_NUMBER: builtins.int
    PRODUCT_ID_FIELD_NUMBER: builtins.int
    REGION_LIST_FIELD_NUMBER: builtins.int
    ADMIN_ROLE_FIELD_NUMBER: builtins.int
    ACCOUNT_LIST_FIELD_NUMBER: builtins.int
    EXECUTION_ROLE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    stack_instance_control: builtins.str
    accept_language: builtins.str
    portfolio_id: builtins.str
    product_id: builtins.str
    @property
    def region_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    admin_role: builtins.str
    @property
    def account_list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    execution_role: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
        stack_instance_control: builtins.str = ...,
        accept_language: builtins.str = ...,
        portfolio_id: builtins.str = ...,
        product_id: builtins.str = ...,
        region_list: collections.abc.Iterable[builtins.str] | None = ...,
        admin_role: builtins.str = ...,
        account_list: collections.abc.Iterable[builtins.str] | None = ...,
        execution_role: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["accept_language", b"accept_language", "account_list", b"account_list", "admin_role", b"admin_role", "description", b"description", "execution_role", b"execution_role", "portfolio_id", b"portfolio_id", "product_id", b"product_id", "region_list", b"region_list", "resource_info", b"resource_info", "stack_instance_control", b"stack_instance_control"]) -> None: ...

global___StackSetConstraint = StackSetConstraint

@typing_extensions.final
class TagOption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACTIVE_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    active: builtins.bool
    value: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        active: builtins.bool = ...,
        value: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active", b"active", "key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___TagOption = TagOption

@typing_extensions.final
class TagOptionAssociation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAG_OPTION_ID_FIELD_NUMBER: builtins.int
    RESOURCE_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    tag_option_id: builtins.str
    resource_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tag_option_id: builtins.str = ...,
        resource_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_id", b"resource_id", "resource_info", b"resource_info", "tag_option_id", b"tag_option_id"]) -> None: ...

global___TagOptionAssociation = TagOptionAssociation



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ComputeNodeGroupXAutoscalingPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_NODES_FIELD_NUMBER: builtins.int
    MIN_NODES_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    max_nodes: builtins.float
    min_nodes: builtins.float
    mode: builtins.str
    def __init__(
        self,
        *,
        max_nodes: builtins.float = ...,
        min_nodes: builtins.float = ...,
        mode: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_nodes", b"max_nodes", "min_nodes", b"min_nodes", "mode", b"mode"]) -> None: ...

global___ComputeNodeGroupXAutoscalingPolicy = ComputeNodeGroupXAutoscalingPolicy

@typing_extensions.final
class ComputeNodeGroupXMaintenanceWindow(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_TIME_FIELD_NUMBER: builtins.int
    start_time: builtins.str
    def __init__(
        self,
        *,
        start_time: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["start_time", b"start_time"]) -> None: ...

global___ComputeNodeGroupXMaintenanceWindow = ComputeNodeGroupXMaintenanceWindow

@typing_extensions.final
class ComputeNodeGroupXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ComputeNodeGroupXTimeouts = ComputeNodeGroupXTimeouts

@typing_extensions.final
class ComputeNodeGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    INITIAL_SIZE_FIELD_NUMBER: builtins.int
    MAINTENANCE_POLICY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NODE_TEMPLATE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    ZONE_FIELD_NUMBER: builtins.int
    AUTOSCALING_POLICY_FIELD_NUMBER: builtins.int
    MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    initial_size: builtins.float
    maintenance_policy: builtins.str
    name: builtins.str
    node_template: builtins.str
    project: builtins.str
    self_link: builtins.str
    size: builtins.float
    zone: builtins.str
    @property
    def autoscaling_policy(self) -> global___ComputeNodeGroupXAutoscalingPolicy: ...
    @property
    def maintenance_window(self) -> global___ComputeNodeGroupXMaintenanceWindow: ...
    @property
    def timeouts(self) -> global___ComputeNodeGroupXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        initial_size: builtins.float = ...,
        maintenance_policy: builtins.str = ...,
        name: builtins.str = ...,
        node_template: builtins.str = ...,
        project: builtins.str = ...,
        self_link: builtins.str = ...,
        size: builtins.float = ...,
        zone: builtins.str = ...,
        autoscaling_policy: global___ComputeNodeGroupXAutoscalingPolicy | None = ...,
        maintenance_window: global___ComputeNodeGroupXMaintenanceWindow | None = ...,
        timeouts: global___ComputeNodeGroupXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["autoscaling_policy", b"autoscaling_policy", "maintenance_window", b"maintenance_window", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["autoscaling_policy", b"autoscaling_policy", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "initial_size", b"initial_size", "maintenance_policy", b"maintenance_policy", "maintenance_window", b"maintenance_window", "name", b"name", "node_template", b"node_template", "project", b"project", "resource_info", b"resource_info", "self_link", b"self_link", "size", b"size", "timeouts", b"timeouts", "zone", b"zone"]) -> None: ...

global___ComputeNodeGroup = ComputeNodeGroup

@typing_extensions.final
class ComputeNodeTemplateXNodeTypeFlexibility(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CPUS_FIELD_NUMBER: builtins.int
    LOCAL_SSD_FIELD_NUMBER: builtins.int
    MEMORY_FIELD_NUMBER: builtins.int
    cpus: builtins.str
    local_ssd: builtins.str
    memory: builtins.str
    def __init__(
        self,
        *,
        cpus: builtins.str = ...,
        local_ssd: builtins.str = ...,
        memory: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpus", b"cpus", "local_ssd", b"local_ssd", "memory", b"memory"]) -> None: ...

global___ComputeNodeTemplateXNodeTypeFlexibility = ComputeNodeTemplateXNodeTypeFlexibility

@typing_extensions.final
class ComputeNodeTemplateXServerBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: builtins.str
    def __init__(
        self,
        *,
        type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___ComputeNodeTemplateXServerBinding = ComputeNodeTemplateXServerBinding

@typing_extensions.final
class ComputeNodeTemplateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete"]) -> None: ...

global___ComputeNodeTemplateXTimeouts = ComputeNodeTemplateXTimeouts

@typing_extensions.final
class ComputeNodeTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class NodeAffinityLabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CPU_OVERCOMMIT_TYPE_FIELD_NUMBER: builtins.int
    CREATION_TIMESTAMP_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    NODE_AFFINITY_LABELS_FIELD_NUMBER: builtins.int
    NODE_TYPE_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REGION_FIELD_NUMBER: builtins.int
    SELF_LINK_FIELD_NUMBER: builtins.int
    NODE_TYPE_FLEXIBILITY_FIELD_NUMBER: builtins.int
    SERVER_BINDING_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    cpu_overcommit_type: builtins.str
    creation_timestamp: builtins.str
    description: builtins.str
    id: builtins.str
    name: builtins.str
    @property
    def node_affinity_labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    node_type: builtins.str
    project: builtins.str
    region: builtins.str
    self_link: builtins.str
    @property
    def node_type_flexibility(self) -> global___ComputeNodeTemplateXNodeTypeFlexibility: ...
    @property
    def server_binding(self) -> global___ComputeNodeTemplateXServerBinding: ...
    @property
    def timeouts(self) -> global___ComputeNodeTemplateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        cpu_overcommit_type: builtins.str = ...,
        creation_timestamp: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
        node_affinity_labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        node_type: builtins.str = ...,
        project: builtins.str = ...,
        region: builtins.str = ...,
        self_link: builtins.str = ...,
        node_type_flexibility: global___ComputeNodeTemplateXNodeTypeFlexibility | None = ...,
        server_binding: global___ComputeNodeTemplateXServerBinding | None = ...,
        timeouts: global___ComputeNodeTemplateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["node_type_flexibility", b"node_type_flexibility", "resource_info", b"resource_info", "server_binding", b"server_binding", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cpu_overcommit_type", b"cpu_overcommit_type", "creation_timestamp", b"creation_timestamp", "description", b"description", "id", b"id", "name", b"name", "node_affinity_labels", b"node_affinity_labels", "node_type", b"node_type", "node_type_flexibility", b"node_type_flexibility", "project", b"project", "region", b"region", "resource_info", b"resource_info", "self_link", b"self_link", "server_binding", b"server_binding", "timeouts", b"timeouts"]) -> None: ...

global___ComputeNodeTemplate = ComputeNodeTemplate



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_ha.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18gcp/gcp_compute_ha.proto\x12\x1aoak9.tython.gcp.compute_ha\x1a\x13shared/shared.proto\">\n\x1c\x43omputeHaVpnGatewayXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"d\n!ComputeHaVpnGatewayXVpnInterfaces\x12\n\n\x02id\x18\x01 \x01(\x01\x12\x1f\n\x17interconnect_attachment\x18\x02 \x01(\t\x12\x12\n\nip_address\x18\x03 \x01(\t\"\xe5\x02\n\x13\x43omputeHaVpnGateway\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12J\n\x08timeouts\x18\x08 \x01(\x0b\x32\x38.oak9.tython.gcp.compute_ha.ComputeHaVpnGatewayXTimeouts\x12U\n\x0evpn_interfaces\x18\t \x03(\x0b\x32=.oak9.tython.gcp.compute_ha.ComputeHaVpnGatewayXVpnInterfaces\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_ha_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEHAVPNGATEWAYXTIMEOUTS._serialized_start=77
  _COMPUTEHAVPNGATEWAYXTIMEOUTS._serialized_end=139
  _COMPUTEHAVPNGATEWAYXVPNINTERFACES._serialized_start=141
  _COMPUTEHAVPNGATEWAYXVPNINTERFACES._serialized_end=241
  _COMPUTEHAVPNGATEWAY._serialized_start=244
  _COMPUTEHAVPNGATEWAY._serialized_end=601
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_os.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x10gcp/gcp_os.proto\x12\x12oak9.tython.gcp.os\x1a\x13shared/shared.proto\"\xd5\x01\n9OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels\x12i\n\x06labels\x18\x01 \x03(\x0b\x32Y.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd5\x01\n9OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels\x12i\n\x06labels\x18\x01 \x03(\x0b\x32Y.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"b\n5OsConfigOsPolicyAssignmentXInstanceFilterXInventories\x12\x15\n\ros_short_name\x18\x01 \x01(\t\x12\x12\n\nos_version\x18\x02 \x01(\t\"\xea\x02\n)OsConfigOsPolicyAssignmentXInstanceFilter\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12g\n\x10\x65xclusion_labels\x18\x02 \x03(\x0b\x32M.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilterXExclusionLabels\x12g\n\x10inclusion_labels\x18\x03 \x03(\x0b\x32M.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilterXInclusionLabels\x12^\n\x0binventories\x18\x04 \x03(\x0b\x32I.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilterXInventories\"r\nEOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXInventoryFilters\x12\x15\n\ros_short_name\x18\x01 \x01(\t\x12\x12\n\nos_version\x18\x02 \x01(\t\"\x8a\x01\nTOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"\x7f\nWOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xf2\x02\nPOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFile\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12u\n\x03gcs\x18\x03 \x01(\x0b\x32h.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXGcs\x12{\n\x06remote\x18\x04 \x01(\x0b\x32k.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFileXRemote\"\x8e\x02\nKOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforce\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x18\n\x10output_file_path\x18\x03 \x01(\t\x12\x0e\n\x06script\x18\x04 \x01(\t\x12r\n\x04\x66ile\x18\x05 \x01(\x0b\x32\x64.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforceXFile\"\x8b\x01\nUOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"\x80\x01\nXOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xf5\x02\nQOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFile\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12v\n\x03gcs\x18\x03 \x01(\x0b\x32i.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXGcs\x12|\n\x06remote\x18\x04 \x01(\x0b\x32l.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFileXRemote\"\x90\x02\nLOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidate\x12\x0c\n\x04\x61rgs\x18\x01 \x03(\t\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x18\n\x10output_file_path\x18\x03 \x01(\t\x12\x0e\n\x06script\x18\x04 \x01(\t\x12s\n\x04\x66ile\x18\x05 \x01(\x0b\x32\x65.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidateXFile\"\xab\x02\nCOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExec\x12p\n\x07\x65nforce\x18\x01 \x01(\x0b\x32_.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXEnforce\x12r\n\x08validate\x18\x02 \x01(\x0b\x32`.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExecXValidate\"\x82\x01\nLOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"w\nOOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xda\x02\nHOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFile\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12m\n\x03gcs\x18\x03 \x01(\x0b\x32`.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXGcs\x12s\n\x06remote\x18\x04 \x01(\x0b\x32\x63.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFileXRemote\"\xf4\x01\nCOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFile\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x13\n\x0bpermissions\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12j\n\x04\x66ile\x18\x05 \x01(\x0b\x32\\.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFileXFile\"V\nFOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXApt\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x87\x01\nQOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"|\nTOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xe9\x02\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSource\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12r\n\x03gcs\x18\x03 \x01(\x0b\x32\x65.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXGcs\x12x\n\x06remote\x18\x04 \x01(\x0b\x32h.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSourceXRemote\"\xce\x01\nFOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDeb\x12\x11\n\tpull_deps\x18\x01 \x01(\x08\x12q\n\x06source\x18\x02 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDebXSource\"Y\nIOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXGooget\x12\x0c\n\x04name\x18\x01 \x01(\t\"\x87\x01\nQOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"|\nTOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xe9\x02\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSource\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12r\n\x03gcs\x18\x03 \x01(\x0b\x32\x65.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXGcs\x12x\n\x06remote\x18\x04 \x01(\x0b\x32h.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSourceXRemote\"\xcf\x01\nFOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsi\x12\x12\n\nproperties\x18\x01 \x03(\t\x12q\n\x06source\x18\x02 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsiXSource\"\x87\x01\nQOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXGcs\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x12\n\ngeneration\x18\x02 \x01(\x01\x12\x0e\n\x06object\x18\x03 \x01(\t\"|\nTOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXRemote\x12\x17\n\x0fsha256_checksum\x18\x01 \x01(\t\x12\x0b\n\x03uri\x18\x02 \x01(\t\"\xe9\x02\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSource\x12\x16\n\x0e\x61llow_insecure\x18\x01 \x01(\x08\x12\x12\n\nlocal_path\x18\x02 \x01(\t\x12r\n\x03gcs\x18\x03 \x01(\x0b\x32\x65.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXGcs\x12x\n\x06remote\x18\x04 \x01(\x0b\x32h.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSourceXRemote\"\xce\x01\nFOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpm\x12\x11\n\tpull_deps\x18\x01 \x01(\x08\x12q\n\x06source\x18\x02 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpmXSource\"V\nFOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXYum\x12\x0c\n\x04name\x18\x01 \x01(\t\"Y\nIOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXZypper\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xc6\x06\nBOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkg\x12\x15\n\rdesired_state\x18\x01 \x01(\t\x12g\n\x03\x61pt\x18\x02 \x01(\x0b\x32Z.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXApt\x12g\n\x03\x64\x65\x62\x18\x03 \x01(\x0b\x32Z.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXDeb\x12m\n\x06googet\x18\x04 \x01(\x0b\x32].oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXGooget\x12g\n\x03msi\x18\x05 \x01(\x0b\x32Z.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXMsi\x12g\n\x03rpm\x18\x06 \x01(\x0b\x32Z.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXRpm\x12g\n\x03yum\x18\x07 \x01(\x0b\x32Z.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXYum\x12m\n\x06zypper\x18\x08 \x01(\x0b\x32].oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkgXZypper\"\xad\x01\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXApt\x12\x14\n\x0c\x61rchive_type\x18\x01 \x01(\t\x12\x12\n\ncomponents\x18\x02 \x03(\t\x12\x14\n\x0c\x64istribution\x18\x03 \x01(\t\x12\x0f\n\x07gpg_key\x18\x04 \x01(\t\x12\x0b\n\x03uri\x18\x05 \x01(\t\"j\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXGoo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"\x95\x01\nMOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXYum\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x10\n\x08gpg_keys\x18\x03 \x03(\t\x12\n\n\x02id\x18\x04 \x01(\t\"\x98\x01\nPOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXZypper\x12\x10\n\x08\x62\x61se_url\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\x10\n\x08gpg_keys\x18\x03 \x03(\t\x12\n\n\x02id\x18\x04 \x01(\t\"\x91\x04\nIOsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepository\x12n\n\x03\x61pt\x18\x01 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXApt\x12n\n\x03goo\x18\x02 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXGoo\x12n\n\x03yum\x18\x03 \x01(\x0b\x32\x61.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXYum\x12t\n\x06zypper\x18\x04 \x01(\x0b\x32\x64.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepositoryXZypper\"\xf2\x03\n>OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResources\x12\n\n\x02id\x18\x01 \x01(\t\x12\x65\n\x04\x65xec\x18\x02 \x01(\x0b\x32W.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXExec\x12\x65\n\x04\x66ile\x18\x03 \x01(\x0b\x32W.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXFile\x12\x63\n\x03pkg\x18\x04 \x01(\x0b\x32V.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXPkg\x12q\n\nrepository\x18\x05 \x01(\x0b\x32].oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResourcesXRepository\"\x93\x02\n4OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroups\x12t\n\x11inventory_filters\x18\x01 \x03(\x0b\x32Y.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXInventoryFilters\x12\x65\n\tresources\x18\x02 \x03(\x0b\x32R.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroupsXResources\"\xe0\x01\n%OsConfigOsPolicyAssignmentXOsPolicies\x12%\n\x1d\x61llow_no_resource_group_match\x18\x01 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04mode\x18\x04 \x01(\t\x12\x61\n\x0fresource_groups\x18\x05 \x03(\x0b\x32H.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPoliciesXResourceGroups\"U\n3OsConfigOsPolicyAssignmentXRolloutXDisruptionBudget\x12\r\n\x05\x66ixed\x18\x01 \x01(\x01\x12\x0f\n\x07percent\x18\x02 \x01(\x01\"\xa3\x01\n\"OsConfigOsPolicyAssignmentXRollout\x12\x19\n\x11min_wait_duration\x18\x01 \x01(\t\x12\x62\n\x11\x64isruption_budget\x18\x02 \x01(\x0b\x32G.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXRolloutXDisruptionBudget\"U\n#OsConfigOsPolicyAssignmentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x80\x05\n\x1aOsConfigOsPolicyAssignment\x12\x10\n\x08\x62\x61seline\x18\x01 \x01(\x08\x12\x0f\n\x07\x64\x65leted\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04\x65tag\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x10\n\x08location\x18\x06 \x01(\t\x12\x0c\n\x04name\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x13\n\x0breconciling\x18\t \x01(\x08\x12\x1c\n\x14revision_create_time\x18\n \x01(\t\x12\x13\n\x0brevision_id\x18\x0b \x01(\t\x12\x15\n\rrollout_state\x18\x0c \x01(\t\x12\x0b\n\x03uid\x18\r \x01(\t\x12V\n\x0finstance_filter\x18\x0e \x01(\x0b\x32=.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXInstanceFilter\x12N\n\x0bos_policies\x18\x0f \x03(\x0b\x32\x39.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXOsPolicies\x12G\n\x07rollout\x18\x10 \x01(\x0b\x32\x36.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXRollout\x12I\n\x08timeouts\x18\x11 \x01(\x0b\x32\x37.oak9.tython.gcp.os.OsConfigOsPolicyAssignmentXTimeouts\x12\x37\n\rresource_info\x18\x12 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc7\x01\n2OsConfigPatchDeploymentXInstanceFilterXGroupLabels\x12\x62\n\x06labels\x18\x01 \x03(\x0b\x32R.oak9.tython.gcp.os.OsConfigPatchDeploymentXInstanceFilterXGroupLabels.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd5\x01\n&OsConfigPatchDeploymentXInstanceFilter\x12\x0b\n\x03\x61ll\x18\x01 \x01(\x08\x12\x1e\n\x16instance_name_prefixes\x18\x02 \x03(\t\x12\x11\n\tinstances\x18\x03 \x03(\t\x12\r\n\x05zones\x18\x04 \x03(\t\x12\\\n\x0cgroup_labels\x18\x05 \x03(\x0b\x32\x46.oak9.tython.gcp.os.OsConfigPatchDeploymentXInstanceFilterXGroupLabels\"?\n\'OsConfigPatchDeploymentXOneTimeSchedule\x12\x14\n\x0c\x65xecute_time\x18\x01 \x01(\t\"e\n\'OsConfigPatchDeploymentXPatchConfigXApt\x12\x10\n\x08\x65xcludes\x18\x01 \x03(\t\x12\x1a\n\x12\x65xclusive_packages\x18\x02 \x03(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\":\n\'OsConfigPatchDeploymentXPatchConfigXGoo\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\x87\x01\nJOsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfigXGcsObject\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x19\n\x11generation_number\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"\xfe\x01\n@OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfig\x12\x1d\n\x15\x61llowed_success_codes\x18\x01 \x03(\x01\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x12\n\nlocal_path\x18\x03 \x01(\t\x12r\n\ngcs_object\x18\x04 \x01(\x0b\x32^.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfigXGcsObject\"\x89\x01\nLOsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfigXGcsObject\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x19\n\x11generation_number\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"\x82\x02\nBOsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfig\x12\x1d\n\x15\x61llowed_success_codes\x18\x01 \x03(\x01\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x12\n\nlocal_path\x18\x03 \x01(\t\x12t\n\ngcs_object\x18\x04 \x01(\x0b\x32`.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfigXGcsObject\"\x9e\x02\n,OsConfigPatchDeploymentXPatchConfigXPostStep\x12t\n\x16linux_exec_step_config\x18\x01 \x01(\x0b\x32T.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPostStepXLinuxExecStepConfig\x12x\n\x18windows_exec_step_config\x18\x02 \x01(\x0b\x32V.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPostStepXWindowsExecStepConfig\"\x86\x01\nIOsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfigXGcsObject\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x19\n\x11generation_number\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"\xfc\x01\n?OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfig\x12\x1d\n\x15\x61llowed_success_codes\x18\x01 \x03(\x01\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x12\n\nlocal_path\x18\x03 \x01(\t\x12q\n\ngcs_object\x18\x04 \x01(\x0b\x32].oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfigXGcsObject\"\x88\x01\nKOsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfigXGcsObject\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x19\n\x11generation_number\x18\x02 \x01(\t\x12\x0e\n\x06object\x18\x03 \x01(\t\"\x80\x02\nAOsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfig\x12\x1d\n\x15\x61llowed_success_codes\x18\x01 \x03(\x01\x12\x13\n\x0binterpreter\x18\x02 \x01(\t\x12\x12\n\nlocal_path\x18\x03 \x01(\t\x12s\n\ngcs_object\x18\x04 \x01(\x0b\x32_.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfigXGcsObject\"\x9b\x02\n+OsConfigPatchDeploymentXPatchConfigXPreStep\x12s\n\x16linux_exec_step_config\x18\x01 \x01(\x0b\x32S.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPreStepXLinuxExecStepConfig\x12w\n\x18windows_exec_step_config\x18\x02 \x01(\x0b\x32U.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPreStepXWindowsExecStepConfig\"y\n1OsConfigPatchDeploymentXPatchConfigXWindowsUpdate\x12\x17\n\x0f\x63lassifications\x18\x01 \x03(\t\x12\x10\n\x08\x65xcludes\x18\x02 \x03(\t\x12\x19\n\x11\x65xclusive_patches\x18\x03 \x03(\t\"z\n\'OsConfigPatchDeploymentXPatchConfigXYum\x12\x10\n\x08\x65xcludes\x18\x01 \x03(\t\x12\x1a\n\x12\x65xclusive_packages\x18\x02 \x03(\t\x12\x0f\n\x07minimal\x18\x03 \x01(\x08\x12\x10\n\x08security\x18\x04 \x01(\x08\"\xad\x01\n*OsConfigPatchDeploymentXPatchConfigXZypper\x12\x12\n\ncategories\x18\x01 \x03(\t\x12\x10\n\x08\x65xcludes\x18\x02 \x03(\t\x12\x19\n\x11\x65xclusive_patches\x18\x03 \x03(\t\x12\x12\n\nseverities\x18\x04 \x03(\t\x12\x15\n\rwith_optional\x18\x05 \x01(\x08\x12\x13\n\x0bwith_update\x18\x06 \x01(\x08\"\x90\x05\n#OsConfigPatchDeploymentXPatchConfig\x12\x1d\n\x15mig_instances_allowed\x18\x01 \x01(\x08\x12\x15\n\rreboot_config\x18\x02 \x01(\t\x12H\n\x03\x61pt\x18\x03 \x01(\x0b\x32;.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXApt\x12H\n\x03goo\x18\x04 \x01(\x0b\x32;.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXGoo\x12S\n\tpost_step\x18\x05 \x01(\x0b\x32@.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPostStep\x12Q\n\x08pre_step\x18\x06 \x01(\x0b\x32?.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXPreStep\x12]\n\x0ewindows_update\x18\x07 \x01(\x0b\x32\x45.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXWindowsUpdate\x12H\n\x03yum\x18\x08 \x01(\x0b\x32;.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXYum\x12N\n\x06zypper\x18\t \x01(\x0b\x32>.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfigXZypper\"m\n@OsConfigPatchDeploymentXRecurringScheduleXMonthlyXWeekDayOfMonth\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\t\x12\x14\n\x0cweek_ordinal\x18\x02 \x01(\x01\"\xb7\x01\n1OsConfigPatchDeploymentXRecurringScheduleXMonthly\x12\x11\n\tmonth_day\x18\x01 \x01(\x01\x12o\n\x11week_day_of_month\x18\x02 \x01(\x0b\x32T.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringScheduleXMonthlyXWeekDayOfMonth\"u\n3OsConfigPatchDeploymentXRecurringScheduleXTimeOfDay\x12\r\n\x05hours\x18\x01 \x01(\x01\x12\x0f\n\x07minutes\x18\x02 \x01(\x01\x12\r\n\x05nanos\x18\x03 \x01(\x01\x12\x0f\n\x07seconds\x18\x04 \x01(\x01\"Q\n2OsConfigPatchDeploymentXRecurringScheduleXTimeZone\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"G\n0OsConfigPatchDeploymentXRecurringScheduleXWeekly\x12\x13\n\x0b\x64\x61y_of_week\x18\x01 \x01(\t\"\xee\x03\n)OsConfigPatchDeploymentXRecurringSchedule\x12\x10\n\x08\x65nd_time\x18\x01 \x01(\t\x12\x19\n\x11last_execute_time\x18\x02 \x01(\t\x12\x19\n\x11next_execute_time\x18\x03 \x01(\t\x12\x12\n\nstart_time\x18\x04 \x01(\t\x12V\n\x07monthly\x18\x05 \x01(\x0b\x32\x45.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringScheduleXMonthly\x12\\\n\x0btime_of_day\x18\x06 \x01(\x0b\x32G.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringScheduleXTimeOfDay\x12Y\n\ttime_zone\x18\x07 \x01(\x0b\x32\x46.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringScheduleXTimeZone\x12T\n\x06weekly\x18\x08 \x01(\x0b\x32\x44.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringScheduleXWeekly\"U\n0OsConfigPatchDeploymentXRolloutXDisruptionBudget\x12\r\n\x05\x66ixed\x18\x01 \x01(\x01\x12\x12\n\npercentage\x18\x02 \x01(\x01\"\x90\x01\n\x1fOsConfigPatchDeploymentXRollout\x12\x0c\n\x04mode\x18\x01 \x01(\t\x12_\n\x11\x64isruption_budget\x18\x02 \x01(\x0b\x32\x44.oak9.tython.gcp.os.OsConfigPatchDeploymentXRolloutXDisruptionBudget\"B\n OsConfigPatchDeploymentXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xeb\x05\n\x17OsConfigPatchDeployment\x12\x13\n\x0b\x63reate_time\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08\x64uration\x18\x03 \x01(\t\x12\n\n\x02id\x18\x04 \x01(\t\x12\x19\n\x11last_execute_time\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x1b\n\x13patch_deployment_id\x18\x07 \x01(\t\x12\x0f\n\x07project\x18\x08 \x01(\t\x12\x13\n\x0bupdate_time\x18\t \x01(\t\x12S\n\x0finstance_filter\x18\n \x01(\x0b\x32:.oak9.tython.gcp.os.OsConfigPatchDeploymentXInstanceFilter\x12V\n\x11one_time_schedule\x18\x0b \x01(\x0b\x32;.oak9.tython.gcp.os.OsConfigPatchDeploymentXOneTimeSchedule\x12M\n\x0cpatch_config\x18\x0c \x01(\x0b\x32\x37.oak9.tython.gcp.os.OsConfigPatchDeploymentXPatchConfig\x12Y\n\x12recurring_schedule\x18\r \x01(\x0b\x32=.oak9.tython.gcp.os.OsConfigPatchDeploymentXRecurringSchedule\x12\x44\n\x07rollout\x18\x0e \x01(\x0b\x32\x33.oak9.tython.gcp.os.OsConfigPatchDeploymentXRollout\x12\x46\n\x08timeouts\x18\x0f \x01(\x0b\x32\x34.oak9.tython.gcp.os.OsConfigPatchDeploymentXTimeouts\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"N\n\x1cOsLoginSshPublicKeyXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xfd\x01\n\x13OsLoginSshPublicKey\x12\x1c\n\x14\x65xpiration_time_usec\x18\x01 \x01(\t\x12\x13\n\x0b\x66ingerprint\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0b\n\x03key\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0c\n\x04user\x18\x06 \x01(\t\x12\x42\n\x08timeouts\x18\x07 \x01(\x0b\x32\x30.oak9.tython.gcp.os.OsLoginSshPublicKeyXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_os_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS_LABELSENTRY._options = None
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS_LABELSENTRY._serialized_options = b'8\001'
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS_LABELSENTRY._options = None
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS_LABELSENTRY._serialized_options = b'8\001'
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS_LABELSENTRY._options = None
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS_LABELSENTRY._serialized_options = b'8\001'
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS._serialized_start=62
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS._serialized_end=275
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS_LABELSENTRY._serialized_start=230
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXEXCLUSIONLABELS_LABELSENTRY._serialized_end=275
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS._serialized_start=278
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS._serialized_end=491
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS_LABELSENTRY._serialized_start=230
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINCLUSIONLABELS_LABELSENTRY._serialized_end=275
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINVENTORIES._serialized_start=493
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTERXINVENTORIES._serialized_end=591
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTER._serialized_start=594
  _OSCONFIGOSPOLICYASSIGNMENTXINSTANCEFILTER._serialized_end=956
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXINVENTORYFILTERS._serialized_start=958
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXINVENTORYFILTERS._serialized_end=1072
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILEXGCS._serialized_start=1075
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILEXGCS._serialized_end=1213
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILEXREMOTE._serialized_start=1215
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILEXREMOTE._serialized_end=1342
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILE._serialized_start=1345
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCEXFILE._serialized_end=1715
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCE._serialized_start=1718
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXENFORCE._serialized_end=1988
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILEXGCS._serialized_start=1991
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILEXGCS._serialized_end=2130
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILEXREMOTE._serialized_start=2133
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILEXREMOTE._serialized_end=2261
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILE._serialized_start=2264
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATEXFILE._serialized_end=2637
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATE._serialized_start=2640
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXECXVALIDATE._serialized_end=2912
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXEC._serialized_start=2915
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXEXEC._serialized_end=3214
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILEXGCS._serialized_start=3217
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILEXGCS._serialized_end=3347
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILEXREMOTE._serialized_start=3349
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILEXREMOTE._serialized_end=3468
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILE._serialized_start=3471
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILEXFILE._serialized_end=3817
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILE._serialized_start=3820
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXFILE._serialized_end=4064
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXAPT._serialized_start=4066
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXAPT._serialized_end=4152
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCEXGCS._serialized_start=4155
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCEXGCS._serialized_end=4290
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCEXREMOTE._serialized_start=4292
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCEXREMOTE._serialized_end=4416
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCE._serialized_start=4419
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEBXSOURCE._serialized_end=4780
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEB._serialized_start=4783
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXDEB._serialized_end=4989
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXGOOGET._serialized_start=4991
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXGOOGET._serialized_end=5080
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCEXGCS._serialized_start=5083
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCEXGCS._serialized_end=5218
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCEXREMOTE._serialized_start=5220
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCEXREMOTE._serialized_end=5344
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCE._serialized_start=5347
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSIXSOURCE._serialized_end=5708
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSI._serialized_start=5711
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXMSI._serialized_end=5918
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCEXGCS._serialized_start=5921
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCEXGCS._serialized_end=6056
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCEXREMOTE._serialized_start=6058
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCEXREMOTE._serialized_end=6182
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCE._serialized_start=6185
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPMXSOURCE._serialized_end=6546
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPM._serialized_start=6549
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXRPM._serialized_end=6755
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXYUM._serialized_start=6757
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXYUM._serialized_end=6843
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXZYPPER._serialized_start=6845
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKGXZYPPER._serialized_end=6934
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKG._serialized_start=6937
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXPKG._serialized_end=7775
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXAPT._serialized_start=7778
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXAPT._serialized_end=7951
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXGOO._serialized_start=7953
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXGOO._serialized_end=8059
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXYUM._serialized_start=8062
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXYUM._serialized_end=8211
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXZYPPER._serialized_start=8214
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORYXZYPPER._serialized_end=8366
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORY._serialized_start=8369
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCESXREPOSITORY._serialized_end=8898
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCES._serialized_start=8901
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPSXRESOURCES._serialized_end=9399
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPS._serialized_start=9402
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIESXRESOURCEGROUPS._serialized_end=9677
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIES._serialized_start=9680
  _OSCONFIGOSPOLICYASSIGNMENTXOSPOLICIES._serialized_end=9904
  _OSCONFIGOSPOLICYASSIGNMENTXROLLOUTXDISRUPTIONBUDGET._serialized_start=9906
  _OSCONFIGOSPOLICYASSIGNMENTXROLLOUTXDISRUPTIONBUDGET._serialized_end=9991
  _OSCONFIGOSPOLICYASSIGNMENTXROLLOUT._serialized_start=9994
  _OSCONFIGOSPOLICYASSIGNMENTXROLLOUT._serialized_end=10157
  _OSCONFIGOSPOLICYASSIGNMENTXTIMEOUTS._serialized_start=10159
  _OSCONFIGOSPOLICYASSIGNMENTXTIMEOUTS._serialized_end=10244
  _OSCONFIGOSPOLICYASSIGNMENT._serialized_start=10247
  _OSCONFIGOSPOLICYASSIGNMENT._serialized_end=10887
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS._serialized_start=10890
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS._serialized_end=11089
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS_LABELSENTRY._serialized_start=230
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTERXGROUPLABELS_LABELSENTRY._serialized_end=275
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTER._serialized_start=11092
  _OSCONFIGPATCHDEPLOYMENTXINSTANCEFILTER._serialized_end=11305
  _OSCONFIGPATCHDEPLOYMENTXONETIMESCHEDULE._serialized_start=11307
  _OSCONFIGPATCHDEPLOYMENTXONETIMESCHEDULE._serialized_end=11370
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXAPT._serialized_start=11372
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXAPT._serialized_end=11473
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXGOO._serialized_start=11475
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXGOO._serialized_end=11533
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXLINUXEXECSTEPCONFIGXGCSOBJECT._serialized_start=11536
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXLINUXEXECSTEPCONFIGXGCSOBJECT._serialized_end=11671
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXLINUXEXECSTEPCONFIG._serialized_start=11674
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXLINUXEXECSTEPCONFIG._serialized_end=11928
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXWINDOWSEXECSTEPCONFIGXGCSOBJECT._serialized_start=11931
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXWINDOWSEXECSTEPCONFIGXGCSOBJECT._serialized_end=12068
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXWINDOWSEXECSTEPCONFIG._serialized_start=12071
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEPXWINDOWSEXECSTEPCONFIG._serialized_end=12329
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEP._serialized_start=12332
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPOSTSTEP._serialized_end=12618
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXLINUXEXECSTEPCONFIGXGCSOBJECT._serialized_start=12621
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXLINUXEXECSTEPCONFIGXGCSOBJECT._serialized_end=12755
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXLINUXEXECSTEPCONFIG._serialized_start=12758
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXLINUXEXECSTEPCONFIG._serialized_end=13010
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXWINDOWSEXECSTEPCONFIGXGCSOBJECT._serialized_start=13013
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXWINDOWSEXECSTEPCONFIGXGCSOBJECT._serialized_end=13149
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXWINDOWSEXECSTEPCONFIG._serialized_start=13152
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEPXWINDOWSEXECSTEPCONFIG._serialized_end=13408
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEP._serialized_start=13411
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXPRESTEP._serialized_end=13694
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXWINDOWSUPDATE._serialized_start=13696
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXWINDOWSUPDATE._serialized_end=13817
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXYUM._serialized_start=13819
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXYUM._serialized_end=13941
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXZYPPER._serialized_start=13944
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIGXZYPPER._serialized_end=14117
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIG._serialized_start=14120
  _OSCONFIGPATCHDEPLOYMENTXPATCHCONFIG._serialized_end=14776
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXMONTHLYXWEEKDAYOFMONTH._serialized_start=14778
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXMONTHLYXWEEKDAYOFMONTH._serialized_end=14887
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXMONTHLY._serialized_start=14890
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXMONTHLY._serialized_end=15073
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXTIMEOFDAY._serialized_start=15075
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXTIMEOFDAY._serialized_end=15192
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXTIMEZONE._serialized_start=15194
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXTIMEZONE._serialized_end=15275
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXWEEKLY._serialized_start=15277
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULEXWEEKLY._serialized_end=15348
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULE._serialized_start=15351
  _OSCONFIGPATCHDEPLOYMENTXRECURRINGSCHEDULE._serialized_end=15845
  _OSCONFIGPATCHDEPLOYMENTXROLLOUTXDISRUPTIONBUDGET._serialized_start=15847
  _OSCONFIGPATCHDEPLOYMENTXROLLOUTXDISRUPTIONBUDGET._serialized_end=15932
  _OSCONFIGPATCHDEPLOYMENTXROLLOUT._serialized_start=15935
  _OSCONFIGPATCHDEPLOYMENTXROLLOUT._serialized_end=16079
  _OSCONFIGPATCHDEPLOYMENTXTIMEOUTS._serialized_start=16081
  _OSCONFIGPATCHDEPLOYMENTXTIMEOUTS._serialized_end=16147
  _OSCONFIGPATCHDEPLOYMENT._serialized_start=16150
  _OSCONFIGPATCHDEPLOYMENT._serialized_end=16897
  _OSLOGINSSHPUBLICKEYXTIMEOUTS._serialized_start=16899
  _OSLOGINSSHPUBLICKEYXTIMEOUTS._serialized_end=16977
  _OSLOGINSSHPUBLICKEY._serialized_start=16980
  _OSLOGINSSHPUBLICKEY._serialized_end=17233
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ecr.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_ecr.proto\x12\x13oak9.tython.aws.ecr\x1a\x13shared/shared.proto\"\x88\x01\n\x19RepositoryLifecyclePolicy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15lifecycle_policy_text\x18\x02 \x01(\t\x12\x13\n\x0bregistry_id\x18\x03 \x01(\t\"\xee\x04\n\nRepository\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12H\n\x10lifecycle_policy\x18\x02 \x01(\x0b\x32..oak9.tython.aws.ecr.RepositoryLifecyclePolicy\x12\x17\n\x0frepository_name\x18\x03 \x01(\t\x12Y\n\x16repository_policy_text\x18\x04 \x03(\x0b\x32\x39.oak9.tython.aws.ecr.Repository.RepositoryPolicyTextEntry\x12\x37\n\x04tags\x18\x05 \x03(\x0b\x32).oak9.tython.aws.ecr.Repository.TagsEntry\x12\x1c\n\x14image_tag_mutability\x18\x06 \x01(\t\x12\x65\n\x1cimage_scanning_configuration\x18\x07 \x03(\x0b\x32?.oak9.tython.aws.ecr.Repository.ImageScanningConfigurationEntry\x1a;\n\x19RepositoryPolicyTextEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x41\n\x1fImageScanningConfigurationEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x03\x45\x43R\x12\x33\n\nrepository\x18\x01 \x03(\x0b\x32\x1f.oak9.tython.aws.ecr.Repositoryb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ecr_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REPOSITORY_REPOSITORYPOLICYTEXTENTRY._options = None
  _REPOSITORY_REPOSITORYPOLICYTEXTENTRY._serialized_options = b'8\001'
  _REPOSITORY_TAGSENTRY._options = None
  _REPOSITORY_TAGSENTRY._serialized_options = b'8\001'
  _REPOSITORY_IMAGESCANNINGCONFIGURATIONENTRY._options = None
  _REPOSITORY_IMAGESCANNINGCONFIGURATIONENTRY._serialized_options = b'8\001'
  _REPOSITORYLIFECYCLEPOLICY._serialized_start=64
  _REPOSITORYLIFECYCLEPOLICY._serialized_end=200
  _REPOSITORY._serialized_start=203
  _REPOSITORY._serialized_end=825
  _REPOSITORY_REPOSITORYPOLICYTEXTENTRY._serialized_start=654
  _REPOSITORY_REPOSITORYPOLICYTEXTENTRY._serialized_end=713
  _REPOSITORY_TAGSENTRY._serialized_start=715
  _REPOSITORY_TAGSENTRY._serialized_end=758
  _REPOSITORY_IMAGESCANNINGCONFIGURATIONENTRY._serialized_start=760
  _REPOSITORY_IMAGESCANNINGCONFIGURATIONENTRY._serialized_end=825
  _ECR._serialized_start=827
  _ECR._serialized_end=885
# @@protoc_insertion_point(module_scope)
